@@ -94,7 +94,7 @@ keyword_merge = function(dt,id = "id",keyword = "keyword",
         .[str_detect(keyword," ")] %>%
         as_tibble() %>%
         # pairwise_count(keyword,id) %>%
-        tidyfst::pairwise_count_dt(id,keyword) %>%
+        tidyfst::pairwise_count_dt(id,keyword,upper = TRUE) %>%
         mutate(value = str_detect(item1,item2)) %>%
         filter(value == TRUE) %>%
         transmute(keyword = item1,replace = item2) %>%
